import { FarmFarmer } from './farmFarmer.type';
import { UserConsultant } from './userConsultant.type';
import { UserFarmer } from './userFarmer.type';
import { InventoryItem } from './../financial/inventory/inventoryItem.type';
import { Animal } from './../zootechnical/animal.type';
import { Expense } from './../financial/expense.type';
import { Address } from '../app/address.type';
import { DairyCompany } from './dairyCompany.type';
import { Entity, Column, ManyToOne, JoinColumn, OneToMany, JoinTable, OneToOne, ManyToMany } from 'typeorm';
import { BasicREntity } from '../basicR.type';
import { IsString, IsNotEmpty, IsOptional, IsDefined } from 'class-validator';
import { Agreement } from './agreement.type';
import { Revenue } from '../financial/revenue.type';
import { FarmConsultant } from './farmConsultant.type';

@Entity()
export class Farm extends BasicREntity {

  @IsNotEmpty()
  @IsString()
  @Column({ nullable: false })
  name: string;

  @IsNotEmpty()
  @OneToOne(type => Address, { nullable: false, cascade: true })
  @JoinColumn()
  address: Address;

  @IsOptional()
  @OneToMany(type => Agreement, agreement => agreement.farm, { nullable: true })
  agreements?: Agreement[];

  @IsOptional()
  @OneToMany(type => UserFarmer, userFarmer => userFarmer.farm, { nullable: true })
  farmers?: UserFarmer[];

  @IsOptional()
  @OneToMany(type => FarmConsultant, farmConsultant => farmConsultant.farm)
  farmConsultant?: FarmConsultant[];

  @IsOptional()
  @OneToMany(type => FarmFarmer, farmFarmer => farmFarmer.farm)
  farmFarmer?: FarmFarmer[];

  @IsOptional()
  @OneToMany(type => Expense, expense => expense.farm, { nullable: true })
  expenses?: Expense[];

  @IsOptional()
  @OneToMany(type => InventoryItem, inventoryItem => inventoryItem.farm, { nullable: true })
  inventoryItems?: InventoryItem[];

  @IsOptional()
  @OneToMany(type => Animal, animal => animal.farm, { nullable: true })
  animals?: Animal[];

  @IsOptional()
  @OneToMany(type => Revenue, revenue => revenue.farm, { nullable: false })
  revenues?: Revenue[];
}